@@ -81,7 +81,7 @@ Hkda.diag <- function(x, x.group, bw="plugin", nstage=2, pilot="samse",
 
 ###############################################################################
 # Classify data set according to discriminant analysis based on training data
-# for 2- to 6-dim
+# for 1- to 6-dim
 #
 # Parameter
 # x - training data
@@ -94,10 +94,52 @@ Hkda.diag <- function(x, x.group, bw="plugin", nstage=2, pilot="samse",
 # Group classification of data set y
 ###############################################################################
 
-kda <- function(x, x.group, Hs, y, prior.prob=NULL)
-{  
-  if (is.data.frame(x)) x <- as.matrix(x)
-  if (is.data.frame(y)) y <- as.matrix(y)
+kda <- function(x, x.group, Hs, hs, y, prior.prob=NULL)
+{
+  if (is.vector(x))
+    disc.gr <- kda.1d(x=x, x.group=x.group, hs=hs, y=y, prior.prob=prior.prob)
+  else
+  {  
+    if (is.data.frame(x)) x <- as.matrix(x)
+    if (is.data.frame(y)) y <- as.matrix(y)
+    gr <- sort(unique(x.group))
+    
+    ## if prior.prob is NULL then use sample proportions
+    if (is.null(prior.prob))
+    {
+      prior.prob <- rep(0, length(gr))
+      for (j in 1:length(gr))
+        prior.prob[j] <- length(which(x.group==gr[j]))
+    prior.prob <- prior.prob/nrow(x)
+    }
+    
+    if (!(identical(all.equal(sum(prior.prob), 1), TRUE)))  
+      stop("Sum of prior weights not equal to 1")
+    
+    ## Compute KDE and weighted KDE 
+    m <- length(gr)
+    fhat <- kda.kde(x, x.group, Hs=Hs, eval.points=y)
+    fhat.wt <- matrix(0, ncol=m, nrow=nrow(y))  
+    
+    for (j in 1:m)
+      fhat.wt[,j] <- fhat$est[[j]]* prior.prob[j]
+    
+    ## Assign y according largest weighted density value 
+    disc.gr.temp <- apply(fhat.wt, 1, which.max)
+    
+    disc.gr <- gr
+    for (j in 1:m)
+    {
+      ind <- which(disc.gr.temp==j)
+      disc.gr[ind] <- gr[j]
+    }
+  }
+  
+  return(disc.gr) 
+}
+
+kda.1d <- function(x, x.group, hs, y, prior.prob=NULL)
+{ 
   gr <- sort(unique(x.group))
 
   # if prior.prob is NULL then use sample proportions
@@ -106,7 +148,7 @@ kda <- function(x, x.group, Hs, y, prior.prob=NULL)
     prior.prob <- rep(0, length(gr))
     for (j in 1:length(gr))
       prior.prob[j] <- length(which(x.group==gr[j]))
-    prior.prob <- prior.prob/nrow(x)
+    prior.prob <- prior.prob/length(x)
   }
   
   if (!(identical(all.equal(sum(prior.prob), 1), TRUE)))  
@@ -114,11 +156,11 @@ kda <- function(x, x.group, Hs, y, prior.prob=NULL)
 
   ## Compute KDE and weighted KDE 
   m <- length(gr)
-  fhat <- kda.kde(x, x.group, Hs, eval.points=y)
-  fhat.wt <- matrix(0, ncol=m, nrow=nrow(y))  
-
+  fhat <- kda.kde(x, x.group, hs=hs, eval.points=y)
+  fhat.wt <- matrix(0, ncol=m, nrow=length(y))  
+  
   for (j in 1:m)
-    fhat.wt[,j] <- fhat$est[[j]]* prior.prob[j]
+    fhat.wt[,j] <- fhat$estimate[[j]]* prior.prob[j]
 
   ## Assign y according largest weighted density value 
   disc.gr.temp <- apply(fhat.wt, 1, which.max)
@@ -215,7 +257,7 @@ compare.kda.cv <- function(x, x.group, bw="plugin",
     H <- Hkda(x, x.group, bw=bw, ...)
 
   ### classify data x using KDA rules based on x itself
-  kda.group <- kda(x, x.group, H, x, prior.prob=prior.prob)
+  kda.group <- kda(x, x.group, Hs=H, y=x, prior.prob=prior.prob)
   comp <- compare(x.group, kda.group)
  
   gr <- sort(unique(x.group)) 
@@ -257,7 +299,7 @@ compare.kda.cv <- function(x, x.group, bw="plugin",
 
     if (trace)
       cat(paste("Processing data item:", i, "\n"))
-    kda.cv.gr[i] <- kda(x[-i,], x.group[-i], H.mod, x, prior.prob=prior.prob)[i]
+    kda.cv.gr[i] <- kda(x[-i,], x.group[-i], Hs=H.mod, y=x, prior.prob=prior.prob)[i]
   }
   
   return(compare(x.group, kda.cv.gr, by.group=by.group)) 
@@ -274,7 +316,7 @@ compare.kda.diag.cv <- function(x, x.group, bw="plugin", prior.prob=NULL,
   d <- ncol(x)
 
   H <- Hkda.diag(x, x.group, bw=bw, ...)
-  kda.group <- kda(x, x.group, H, x, prior.prob=prior.prob)
+  kda.group <- kda(x, x.group, Hs=H, y=x, prior.prob=prior.prob)
   comp <- compare(x.group, kda.group)
  
   gr <- sort(unique(x.group)) 
@@ -296,43 +338,15 @@ compare.kda.diag.cv <- function(x, x.group, bw="plugin", prior.prob=NULL,
     H.mod[((ind-1)*d+1):(ind*d),] <- H.temp
     if (trace)
       cat(paste("Processing data item:", i, "\n"))
-    kda.cv.gr[i] <- kda(x[-i,], x.group[-i], H.mod, x, prior.prob=prior.prob)[i]  
+    kda.cv.gr[i] <- kda(x[-i,], x.group[-i], Hs=H.mod, y=x, prior.prob=prior.prob)[i]  
   }
   return(compare(x.group, kda.cv.gr, by.group=by.group)) 
 }
 
-###############################################################################
-# Computes cross-validated misclassification rates (for use when test data =
-# training data) for parametric DA
-#
-# Parameter
-# x - training data
-# x.group - group variable for x
-# prior.prob - prior probabilities
-# type - "line" - linear disc.
-#      - "quad" - quadratic disc.
-###############################################################################
-
-compare.pda.cv <- function(x, x.group, type="quad", prior.prob=NULL,
-    by.group=FALSE)
-{
-  n <- nrow(x)
-  d <- ncol(x)
-
-  pda.group <- pda(x, x.group, x, prior.prob=prior.prob, type=type)
-  comp <- compare(x.group, pda.group)
-  
-  pda.cv.gr <- vector()
-  for (i in 1:n)
-    pda.cv.gr[i] <-
-      as.vector(pda(x[-i,], x.group[-i], x, prior.prob=prior.prob, type=type))[i]
-
-  return(compare(x.group, pda.cv.gr, by.group=by.group)) 
-}
 
 
 ###############################################################################
-# KDEs of individual densities for KDA - only for 2-dim 
+# KDEs of individual densities for KDA - 1- to 3-dim
 #
 # Parameters
 # x - data values
@@ -347,67 +361,124 @@ compare.pda.cv <- function(x, x.group, type="quad", prior.prob=NULL,
 # H - list of bandwidth matrices
 ##############################################################################
 
-kda.kde <- function(x, x.group, Hs, gridsize, supp=3.7, eval.points=NULL)
+kda.kde <- function(x, x.group, Hs, hs, prior.prob=NULL, gridsize, supp=3.7, eval.points=NULL)
 {
-  if (is.data.frame(x)) x <- as.matrix(x)
-  grlab <- sort(unique(x.group))
-  m <- length(grlab)
-  d <- ncol(x)
-   
-  if (missing(gridsize)) 
-    gridsize <- rep(100,d)
-   
-  # find largest bandwidth matrix to initialise grid
-  detH <- vector() 
-  for (j in 1:m)
-    detH[j] <- det(Hs[((j-1)*d+1) : (j*d),])  
-  Hmax.ind <- which.max(detH)
-  Hmax <- Hs[((Hmax.ind-1)*d+1) : (Hmax.ind*d),]
-
-  # initialise grid 
-  gridx <- make.grid.ks(x, matrix.sqrt(Hmax), tol=supp, gridsize=gridsize) 
-  suppx <- make.supp(x, matrix.sqrt(Hmax), tol=supp)  
-  grid.pts <- find.gridpts(gridx, suppx)
-  fhat.list <- list()
-    
-  for (j in 1:m)
+  if (is.vector(x))
   {
-    xx <- x[x.group==grlab[j],]
-    H <- Hs[((j-1)*d+1) : (j*d),]
-
-    # compute individual density estimate
-    if (is.null(eval.points))
-    {
-      xx.grid.pts <- list()
-      xx.grid.pts$minx <- grid.pts$minx[x.group==grlab[j],]
-      xx.grid.pts$maxx <- grid.pts$maxx[x.group==grlab[j],]
-      if (d==2)
-        fhat.temp <- kde.grid.2d(xx, H, gridx=gridx, supp=supp, grid.pts=xx.grid.pts)
-      else if (d==3)
-        fhat.temp <- kde.grid.3d(xx, H, gridx=gridx, supp=supp, grid.pts=xx.grid.pts)
-    }
-    else
-      fhat.temp <- kde.points(xx, H, eval.points=eval.points)
-
-    fhat.list$x <- c(fhat.list$x, list(xx))
-    fhat.list$eval.points <- fhat.temp$eval.points
-    fhat.list$estimate <- c(fhat.list$estimate, list(fhat.temp$est))
-    fhat.list$H <- c(fhat.list$H, list(fhat.temp$H))
+    if (missing(gridsize))  gridsize <- 101
+    fhat.list <- kda.kde.1d(x=x, x.group=x.group, hs=hs, prior.prob=prior.prob, gridsize=gridsize, supp=supp, eval.points=eval.points)
   }
-
-  fhat.list$x.group <- x.group
-  pr <- rep(0, length(grlab))
-  for (j in 1:length(grlab))
-    pr[j] <- length(which(x.group==grlab[j]))
-  pr <- pr/nrow(x)
-  fhat.list$prior.prob <- pr
-  fhat.list$type <- "kernel"
+  else
+  {
+    if (is.data.frame(x)) x <- as.matrix(x)
+    grlab <- sort(unique(x.group))
+    m <- length(grlab)
+    d <- ncol(x)
+    
+    if (missing(gridsize)) 
+      gridsize <- rep(51,d)
+      #else if (d==3) gridsize <- rep(51, d)
+    
+    ## find largest bandwidth matrix to initialise grid
+    detH <- vector() 
+    for (j in 1:m)
+      detH[j] <- det(Hs[((j-1)*d+1) : (j*d),])  
+    Hmax.ind <- which.max(detH)
+    Hmax <- Hs[((Hmax.ind-1)*d+1) : (Hmax.ind*d),]
+    
+    ## initialise grid 
+    gridx <- make.grid.ks(x, matrix.sqrt(Hmax), tol=supp, gridsize=gridsize) 
+    suppx <- make.supp(x, matrix.sqrt(Hmax), tol=supp)  
+    grid.pts <- find.gridpts(gridx, suppx)
+    fhat.list <- list()
+    
+    for (j in 1:m)
+    {
+      xx <- x[x.group==grlab[j],]
+      H <- Hs[((j-1)*d+1) : (j*d),]
+      
+      ## compute individual density estimate
+      if (is.null(eval.points))
+      {
+        xx.grid.pts <- list()
+        xx.grid.pts$minx <- grid.pts$minx[x.group==grlab[j],]
+        xx.grid.pts$maxx <- grid.pts$maxx[x.group==grlab[j],]
+        if (d==2)
+          fhat.temp <- kde.grid.2d(xx, H, gridx=gridx, supp=supp, grid.pts=xx.grid.pts)
+        else if (d==3)
+          fhat.temp <- kde.grid.3d(xx, H, gridx=gridx, supp=supp, grid.pts=xx.grid.pts)
+      }
+      else
+        fhat.temp <- kde.points(xx, H, eval.points=eval.points)
+      
+      fhat.list$x <- c(fhat.list$x, list(xx))
+      fhat.list$eval.points <- fhat.temp$eval.points
+      fhat.list$estimate <- c(fhat.list$estimate, list(fhat.temp$est))
+      fhat.list$H <- c(fhat.list$H, list(fhat.temp$H))
+    }
+    
+    fhat.list$x.group <- x.group
+    pr <- rep(0, length(grlab))
+    for (j in 1:length(grlab))
+      pr[j] <- length(which(x.group==grlab[j]))
+    pr <- pr/nrow(x)
+    fhat.list$prior.prob <- pr
+    #fhat.list$type <- "kernel"
   
-  class(fhat.list) <- "dade"
+    class(fhat.list) <- "kda.kde"
+  }
   
   return(fhat.list)
 }
 
+kda.kde.1d <- function(x, x.group, hs, prior.prob, gridsize, supp, eval.points)
+{
+  grlab <- sort(unique(x.group))
+  m <- length(grlab)
+
+  hmax <- max(hs)
+  range.x <- c(min(x) - supp*hmax, max(x) + supp*hmax)
+  fhat.list <- list()
+  for (j in 1:m)
+  {
+    xx <- x[x.group==grlab[j]]
+    h <- hs[j]
+
+    # compute individual density estimate
+    if (is.null(eval.points))
+    {
+      fhat.temp <- bkde(x=xx, bandwidth=h, gridsize=gridsize, range.x=range.x)
+      fhat.list$estimate <- c(fhat.list$estimate, list(fhat.temp$y))
+    }
+    else
+    {
+      fhat.temp <- kde.points.1d(x=xx, h=h, eval.points=eval.points)
+      fhat.list$estimate <- c(fhat.list$estimate, list(fhat.temp$estimate))
+    }
+    fhat.list$x <- c(fhat.list$x, list(xx))
+    fhat.list$eval.points <- fhat.temp$x
+    
+    fhat.list$h <- c(fhat.list$h, h)
+  }
+
+  fhat.list$x.group <- x.group
+  if (is.null(prior.prob))
+  {
+    pr <- rep(0, length(grlab))
+    for (j in 1:length(grlab))
+      pr[j] <- length(which(x.group==grlab[j]))
+    pr <- pr/length(x)
+    fhat.list$prior.prob <- pr
+  }
+  else
+    fhat.list$prior.prob <- prior.prob
+  #fhat.list$type <- "kernel"
+  
+  class(fhat.list) <- "kda.kde"
+  
+  return(fhat.list)
+  
+}
 
 ##############################################################################
 # Plot KDE of individual densities and partition - only for 2-dim
@@ -422,36 +493,80 @@ kda.kde <- function(x, x.group, Hs, gridsize, supp=3.7, eval.points=NULL)
 ##############################################################################
 
 
-plot.dade <- function(x, y, y.group, prior.prob=NULL, display="part",
-    cont=NULL, ncont=NULL, ...)
+plot.kda.kde <- function(x, y, y.group, ...) 
 {
-  d <- ncol(x$x[[1]])
-
-  if (d==2)
-  {
-    if (is.null(cont))
-      cont <- c(25,50,75)
-    plotdade.2d(x, y, y.group, prior.prob=prior.prob, display=display,
-                cont=cont, ncont=ncont, ...)
-  }
-  else if (d==3)
-  {
-    if (is.null(cont))
-      cont <- c(25,50)
-    plotdade.3d(x, y, y.group, prior.prob=prior.prob, display="rgl",
-                cont=cont, ...)
+  if (is.vector(x$x[[1]]))
+    plotkda.kde.1d(x=x, y=y, y.group=y.group, ...)
+  else
+  {  
+    d <- ncol(x$x[[1]])
+    
+    if (d==2)
+      plotkda.kde.2d(x=x, y=y, y.group=y.group, ...) 
+    else if (d==3)
+      plotkda.kde.3d(x=x, y=y, y.group=y.group, ...) 
   }
 }
 
-plotdade.2d <- function(x, y, y.group, prior.prob=NULL, display="part",
-    cont=c(25,50,75), ncont=NULL, xlim, ylim, xlabs, ylabs,
-    drawlabels=TRUE, cex=1, pch, lty, col, lcol, ptcol, ...)
+
+plotkda.kde.1d <- function(x, y, y.group, prior.prob=NULL, xlim, ylim, xlab="x", ylab="Weighted density function", drawpoints=TRUE, lty, lcol, col, ptcol, ...)
+{ 
+  fhat <- x
+  
+  m <- length(fhat$x)
+  ##type <- substr(fhat$type,1,1)
+  eval1 <- fhat$eval.points
+
+  if (is.null(prior.prob))
+    prior.prob <- fhat$prior.prob
+  
+  if (m != length(prior.prob))
+    stop("Prior prob. vector not same length as number of components in fhat")
+  if (!(identical(all.equal(sum(prior.prob), 1), TRUE)))  
+    stop("Sum of prior weights not equal to 1")
+
+  weighted.fhat <- matrix(0, nrow=length(fhat$eval.points), ncol=m) 
+  for (j in 1:m)
+    weighted.fhat[,j] <- fhat$estimate[[j]]*fhat$prior.prob[j]
+  
+  if (missing(xlim)) xlim <- range(fhat$eval.points)
+  if (missing(ylim)) ylim <- range(weighted.fhat)
+  if (missing(lty)) lty <- 1:m
+  if (missing(lcol)) lcol <- 1:m
+  if (missing(col)) col <- 1:m
+  if (missing(ptcol)) ptcol <- rep("blue", m)
+  
+
+  plot(fhat$eval.points, weighted.fhat[,1], type="l", xlab=xlab, ylab=ylab, xlim=xlim, ylim=ylim, lty=lty[1], col=lcol[1], ...)
+  
+  if (m > 1)
+    for (j in 2:m)
+      lines(fhat$eval.points, weighted.fhat[,j], lty=lty[j], col=lcol[j], ...)
+
+  eval.points.gr <- apply(weighted.fhat, 1, which.max)
+  for (j in 1:m)
+  {
+    rug(fhat$eval.points[eval.points.gr==j], col=col[j])
+    if (drawpoints)
+      rug(fhat$x[[j]], col=ptcol[j], ticksize=-0.03)
+  }
+  
+  if (!missing(y.group)) y.gr <- sort(unique(y.group))
+  if (!missing(y))
+    for (j in 1:length(y.gr))
+      rug(y[y.group==y.gr[j]], col=ptcol[j], ticksize=-0.03)
+}
+
+
+plotkda.kde.2d <- function(x, y, y.group, prior.prob=NULL, 
+    cont=c(25,50,75), ncont=NULL, xlim, ylim, xlab, ylab,
+    drawpoints=TRUE, drawlabels=TRUE, cex=1, pch, lty, col, lcol, ptcol, ...)
 { 
   fhat <- x
   
   d <- 2
   m <- length(fhat$x)
-  type <- substr(fhat$type,1,1)
+  ##type <- substr(fhat$type,1,1)
   eval1 <- fhat$eval.points[[1]]
   eval2 <- fhat$eval.points[[2]]
   
@@ -465,32 +580,30 @@ plotdade.2d <- function(x, y, y.group, prior.prob=NULL, display="part",
   x.names <- colnames(fhat$x[[1]]) 
   if (!is.null(x.names))
   {
-    if (missing(xlabs))
-      xlabs <- x.names[1]
-    if (missing(ylabs))
-      ylabs <- x.names[2]
+    if (missing(xlab)) xlab <- x.names[1]
+    if (missing(ylab)) ylab <- x.names[2]
   }
   else
   {
-    xlabs="x"
-    ylabs="y"
+    xlab="x"
+    ylab="y"
   }
-  
-  if (missing(y)) 
-    plot(fhat$x[[1]], type="n", xlab=xlabs, ylab=ylabs, xlim=xlim, ylim=ylim, ...)
-  else
-    plot(y,  type="n", xlab=xlabs, ylab=ylabs, xlim=xlim, ylim=ylim, ...)
-  
+
   if (is.null(prior.prob))
     prior.prob <- fhat$prior.prob
-  
+
   if (m != length(prior.prob))
     stop("Prior prob. vector not same length as number of components in fhat")
   if (!(identical(all.equal(sum(prior.prob), 1), TRUE)))  
     stop("Sum of prior weights not equal to 1")
-
-  if (display=="part")
-  {
+  
+  if (missing(y)) 
+    plot(fhat$x[[1]], type="n", xlab=xlab, ylab=ylab, xlim=xlim, ylim=ylim, ...)
+  else
+    plot(y, type="n", xlab=xlab, ylab=ylab, xlim=xlim, ylim=ylim, ...)
+  
+  #if (display=="part")
+  #{
     class.grid <- array(0, dim=dim(fhat$est[[1]]))
     temp <- matrix(0, ncol=length(fhat$est), nrow=nrow(fhat$est[[1]]))
     for (j in 1:ncol(fhat$est[[1]]))
@@ -504,7 +617,7 @@ plotdade.2d <- function(x, y, y.group, prior.prob=NULL, display="part",
     if (missing(col)) col <- heat.colors(m)
     image(fhat$eval[[1]], fhat$eval[[2]], class.grid,col=col, xlim=xlim,
           ylim=ylim, add=TRUE, ...)
-  }
+  #}
   
   dobs <- numeric(0)
   xx <- numeric(0)
@@ -521,34 +634,25 @@ plotdade.2d <- function(x, y, y.group, prior.prob=NULL, display="part",
   for (j in 1:m)
     xx <- rbind(xx, fhat$x[[j]])
   if (!missing(y.group)) y.gr <- sort(unique(y.group))
+
   for (j in 1:m)
   {
-    if (missing(y))
-      points(fhat$x[[j]], cex=cex, pch=pch[j], col=ptcol[1])
-    else 
+    if (drawpoints)
     {
-      if (missing(y.group))
-        points(y, cex=cex, col=ptcol[1])
-      else
-        points(y[y.group==y.gr[j],], cex=cex, pch=pch[j], col=ptcol[j])
+      if (missing(y))
+        points(fhat$x[[j]], cex=cex, pch=pch[j], col=ptcol[1])
+      else 
+      {
+        if (missing(y.group))
+          points(y, cex=cex, col=ptcol[1])
+        else
+          points(y[y.group==y.gr[j],], cex=cex, pch=pch[j], col=ptcol[j]) 
+      }
+    }
+    
+    dobs <- c(dobs, kde(fhat$x[[j]], fhat$H[[j]], eval.points=xx)$estimate
+              * prior.prob[j])
     
-    }
-    if (type=="k")
-      dobs <- c(dobs, kde(fhat$x[[j]], fhat$H[[j]], eval.points=xx)$estimate
-                * prior.prob[j])
-    else if (type=="q")
-    {
-      xbarj <- apply(fhat$x[[j]], 2, mean)
-      Sj <- var(fhat$x[[j]])
-      dobs <- c(dobs, dmvnorm.mixt(x=fhat$x[[j]], mus=xbarj, Sigmas=Sj, props=1)
-                * prior.prob[j])
-    }
-    else if (type=="l")
-    {
-      xbarj <- apply(fhat$x[[j]], 2, mean)      
-      dobs <- c(dobs, dmvnorm.mixt(x=fhat$x[[j]], mus=xbarj, Sigmas=S, props=1)
-                * prior.prob[j])
-    }
   }
 
   hts <- quantile(dobs, prob = (100 - cont)/100)
@@ -572,16 +676,16 @@ plotdade.2d <- function(x, y, y.group, prior.prob=NULL, display="part",
 
 
 
-plotdade.3d <- function(x, y, y.group, prior.prob=NULL, display="rgl",
+plotkda.kde.3d <- function(x, y, y.group, prior.prob=NULL,
     cont=c(25,50), colors, alphavec, origin=c(0,0,0),
-    endpts, xlabs, ylabs, zlabs, drawpoints=TRUE, size=3,
+    endpts, xlab, ylab, zlab, drawpoints=TRUE, size=3,
     ptcol, ...)
 { 
   fhat <- x
    
   d <- 3
   m <- length(fhat$x)
-  type <- substr(fhat$type,1,1)
+  ##type <- substr(fhat$type,1,1)
   eval1 <- fhat$eval.points[[1]]
   eval2 <- fhat$eval.points[[2]]
   eval3 <- fhat$eval.points[[3]]
@@ -603,38 +707,25 @@ plotdade.3d <- function(x, y, y.group, prior.prob=NULL, display="rgl",
   x.names <- colnames(fhat$x[[1]]) 
   if (!is.null(x.names))
   {
-    if (missing(xlabs))
-      xlabs <- x.names[1]
-    if (missing(ylabs))
-      ylabs <- x.names[2]
-    if (missing(zlabs))
-      zlabs <- x.names[3]
+    if (missing(xlab)) xlab <- x.names[1]
+    if (missing(ylab)) ylab <- x.names[2]
+    if (missing(zlab)) zlab <- x.names[3]
   }
   else
   {
-    xlabs="x"
-    ylabs="y"
-    zlabs="z"
+    xlab="x"
+    ylab="y"
+    zlab="z"
   }
   
   ncont <- length(cont)
   
-  if (missing(alphavec)) alphavec <- seq(0.1,0.5,length=ncont)
+  if (missing(alphavec)) alphavec <- seq(0.1,0.3,length=ncont)
   if (missing(colors)) colors <- heat.colors(m)
   if (missing(ptcol)) ptcol <- rep("blue", m)
                  
   dobs <- numeric(0)
   xx <- numeric(0)
-  S <- 0
-  n <- 0 
-
-  for (j in 1:m)
-  {
-    n <- nrow(fhat$x[[j]])
-    S <- S + nrow(fhat$x[[j]]) * var(fhat$x[[j]])
-  }
-  S <- S/(n - m)
-
 
   for (j in 1:m)
     xx <- rbind(xx, fhat$x[[j]])
@@ -643,24 +734,9 @@ plotdade.3d <- function(x, y, y.group, prior.prob=NULL, display="rgl",
   x.gr <- sort(unique(fhat$x.group))
 
   for (j in 1:m)
-  {
-    if (type=="k")
-      dobs <- c(dobs, kde(fhat$x[[j]], fhat$H[[j]], eval.points=xx)$estimate
-                * prior.prob[j])
-    else if (type=="q")
-    {
-      xbarj <- apply(fhat$x[[j]], 2, mean)
-      Sj <- var(fhat$x[[j]])
-      dobs <- c(dobs, dmvnorm.mixt(x=fhat$x[[j]], mus=xbarj, Sigmas=Sj, props=1)
-                * prior.prob[j])
-    }
-    else if (type=="l")
-    {
-      xbarj <- apply(fhat$x[[j]], 2, mean)      
-      dobs <- c(dobs, dmvnorm.mixt(x=fhat$x[[j]], mus=xbarj, Sigmas=S, props=1)
-                * prior.prob[j])
-    }
-  }
+    dobs <- c(dobs, kde(fhat$x[[j]], fhat$H[[j]], eval.points=xx)$estimate
+              * prior.prob[j])
+
   
   hts <- quantile(dobs, prob = (100-cont)/100)
 
@@ -679,185 +755,32 @@ plotdade.3d <- function(x, y, y.group, prior.prob=NULL, display="rgl",
     {
       if (missing(y))
         points3d(fhat$x[[j]][,1], fhat$x[[j]][,2], fhat$x[[j]][,3],
-                    color=ptcol[j], size=size)
+                    color=ptcol[j], size=size, alpha=1)
       else
       {
         if (missing(y.group))
-          points3d(y[,1], y[,2], y[,3], color=ptcol, size=size)
+          points3d(y[,1], y[,2], y[,3], color=ptcol, size=size, alpha=1)
         else
         {
           y.temp <- y[y.group==x.gr[j],]
           if (nrow(y.temp)>0)
-            points3d(y.temp[,1], y.temp[,2], y.temp[,3], color=ptcol[j], size=size)
+            points3d(y.temp[,1], y.temp[,2], y.temp[,3], color=ptcol[j], size=size, alpha=1)
         }
       }
     }
   }
   
   lines3d(c(origin[1],endpts[1]),rep(origin[2],2),rep(origin[3],2),size=3,
-          color="black")
+          color="black", alpha=1)
   lines3d(rep(origin[1],2),c(origin[2],endpts[2]),rep(origin[3],2),size=3,
-          color="black")
+          color="black", alpha=1)
   lines3d(rep(origin[1],2),rep(origin[2],2),c(origin[3],endpts[3]),size=3,
-          color="black")
+          color="black", alpha=1)
 
-  texts3d(endpts[1],origin[2],origin[3],xlabs,color="black",size=3)
-  texts3d(origin[1],endpts[2],origin[3],ylabs,color="black",size=3)
-  texts3d(origin[1],origin[2],endpts[3],zlabs,color="black",size=3)
+  texts3d(endpts[1],origin[2],origin[3],xlab,color="black",size=3, alpha=1)
+  texts3d(origin[1],endpts[2],origin[3],ylab,color="black",size=3, alpha=1)
+  texts3d(origin[1],origin[2],endpts[3],zlab,color="black",size=3, alpha=1)
 }
 
 
 
-###############################################################################
-# Classify data set according to discriminant analysis based on training data
-# using linear or quadratic discrimination 
-#
-# Parameter
-# x - training data
-# x.group - group variable for x
-# y - data values to be classified
-# prior.prob - prior probabilities
-# type - "line" - linear disc.
-#      - "quad" - quadratic disc.
-#
-# Returns
-# Group classification of data set y
-###############################################################################
-
-
-pda <- function(x, x.group, y, prior.prob=NULL, type="quad")
-{  
-  if (is.data.frame(x)) x <- as.matrix(x)
-  if (is.data.frame(y)) y <- as.matrix(y)
-  gr <- sort(unique(x.group))
-  
-  if (is.null(prior.prob))
-  {
-    prior.prob <- rep(0, length(gr))
-    for (j in 1:length(gr))
-      prior.prob[j] <- length(which(x.group==gr[j]))
-    prior.prob <- prior.prob/nrow(x)
-  }
-  
-  if (!(identical(all.equal(sum(prior.prob), 1), TRUE)))  
-    stop("Sum of prior weights not equal to 1")
-  
-  if (substr(type,1,1)=="q")
-  {
-    x.qda <- qda(x, x.group)
-    disc.gr <- predict(x.qda, y, dimen=ncol(x), prior=prior.prob)$class
-  }
-  else
-  {
-    x.lda <- lda(x, x.group)
-    disc.gr <- predict(x.lda, y, dimen=ncol(x), prior=prior.prob)$class 
-  }
-  return(disc.gr) 
-}
-
-##############################################################################
-# Compute density estimate of individual densities and classifcation region
-# for parametric DA - for 2-d and 3-d only
-#
-# Parameters
-# x - training data
-# x.group - training data group labels 
-# type - "line" - linear disc.
-#      - "quad" - quadratic disc.
-#
-# Returns 
-# List with components (class dade)
-# x - list of data values
-# eval.points - evaluation points of dnesity estimate
-# estimate - list of density estimate 
-##############################################################################
-
-pda.pde <- function(x, x.group, gridsize, type="quad", xlim, ylim, zlim)
-{
-  n <- nrow(x)
-  d <- ncol(x)
-  
-  gr <- sort(unique(x.group))
-  typ <- substr(type,1,1) 
-  if (missing(xlim))
-    xlim <- range(x[,1])
-  if (missing(ylim))
-    ylim <- range(x[,2])
-  if (missing(zlim) & d==3)
-    zlim <- range(x[,3])
-  if (missing(gridsize)) 
-    gridsize <- rep(100,d)
-
-  if (d==2)
-  {  
-    ex <- seq(xlim[1]-abs(xlim[1])/10, xlim[2]+abs(xlim[2])/10, length=gridsize[1])
-    ey <- seq(ylim[1]-abs(ylim[1])/10, ylim[2]+abs(ylim[2])/10, length=gridsize[2])
-    xy <- permute(list(ex, ey))
-  }
-  else if (d==3)
-  {
-    ex <- seq(xlim[1]-abs(xlim[1])/10, xlim[2]+abs(xlim[2])/10, length=gridsize[1])
-    ey <- seq(ylim[1]-abs(ylim[1])/10, ylim[2]+abs(ylim[2])/10, length=gridsize[2])
-    ez <- seq(zlim[1]-abs(zlim[1])/10, zlim[2]+abs(ylim[2])/10, length=gridsize[3])
-    xyz <- permute(list(ex, ey, ez))
-  }
-  
-  fhat <- list()
-  fhat$x <- list()
-  if (d==2)
-    fhat$eval.points <- list(ex, ey)
-  else if(d==3)
-    fhat$eval.points <- list(ex, ey, ez)
-
-  fhat$estimate <- list()
-  dens.mat <- list()
-
- 
-  S <- 0
-  for (i in 1:length(gr))
-  {
-    xi <- x[x.group==gr[i],]
-    Si <- var(xi)
-    S <- S + nrow(xi)*Si
-  }
-  S <- S/(n - length(gr))
- 
-  for (i in 1:length(gr))
-  {
-    xi <- x[x.group==gr[i],]
-    xbari <- apply(xi, 2, mean)
-    Si <- var(xi)
-    fhat$x[[i]] <- xi
-
-    if (d==2)
-    {
-      if (typ=="q")
-        dens <- dmvnorm.mixt(xy, mu=xbari, Sigma=Si, props=1)
-      else if (typ=="l")
-        dens <- dmvnorm.mixt(xy, mu=xbari, Sigma=S, props=1)
-      fhat$estimate[[i]] <- matrix(dens, nc=gridsize[1], byrow=FALSE)
-    }
-    else if (d==3)
-    {
-      if (typ=="q")
-        dens <- dmvnorm.mixt(xyz, mu=xbari, Sigma=Si, props=1)
-      else if (typ=="l")
-        dens <- dmvnorm.mixt(xyz, mu=xbari, Sigma=S, props=1)
-      fhat$estimate[[i]] <- array(dens, dim=gridsize)
-    }
-  }
-
-  fhat$x.group <- x.group
-  prior.prob <- rep(0, length(gr))
-  for (j in 1:length(gr))
-    prior.prob[j] <- length(which(x.group==gr[j]))
-  prior.prob <- prior.prob/nrow(x)
-  fhat$prior.prob <- prior.prob
-  
-  fhat$type <- type
-  
-  class(fhat) <- "dade"
-  
-  return(fhat)
-}
-
